#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.4.0
visibility:           public
id:                   warp-3.4.0-KVj6SgAA5taGPrWBAzaxbi
key:                  warp-3.4.0-KVj6SgAA5taGPrWBAzaxbi
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  b1b8fa8fa1430475ae6df301d714fa34
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.4.0-KVj6SgAA5taGPrWBAzaxbi
depends:
    array-0.5.6.0 auto-update-0.1.6-7UkzsULnlI91Wm5SlYstZN
    base-4.18.2.1 bsb-http-chunked-0.0.0.4-C86SOPaa3qrDAjTN5aDWla
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-6RlPO9Qfa9fCrnhTKB14aA
    containers-0.6.7 crypton-x509-1.7.7-8HSoUeIcdj3jfotIJFp89
    ghc-prim-0.10.0 hashable-1.4.7.0-Eia1GH7GKUH7V9HVPMehAJ
    http-date-0.0.11-DrhZK8y2rDnEa0QYv5ltou
    http-types-0.12.4-AW38QdPURmwEzxajknpV4M
    http2-5.1.4-9EOJ80p6GB25oTrZ1jAlBM
    iproute-1.7.15-568Ci2u9tFlISgifunJaXZ
    network-3.1.4.0-8HZ2mHT7KyE1ZVQfwLbJCE
    recv-0.1.1-IZNsT56xq9BFTUn0mOR2bf
    simple-sendfile-0.2.32-Ikwh4qtrPvt6YlXPNqNRR7 stm-2.5.1.0
    streaming-commons-0.2.3.1-B7SNt6PT5SZBQHQr4Vzf6t text-2.0.2
    time-manager-0.0.1-DOSU1pYmta5JIPGoFeIEJL unix-2.8.4.0
    unliftio-0.2.25.1-DbrmKftQGxvGrD1b1WeeCx
    vault-0.3.2.0-LHQ2IEBELM8BdBB6PJ9OJm
    wai-3.2.5-ASI3vrqqbYdKQFiHLhloQV word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

